nltk.misc package
=================

Submodules
----------

.. toctree::
   :maxdepth: 4

   nltk.misc.babelfish
   nltk.misc.chomsky
   nltk.misc.minimalset
   nltk.misc.sort
   nltk.misc.wordfinder

Module contents
---------------

.. automodule:: nltk.misc
   :members:
   :undoc-members:
   :show-inheritance:
